% generalized script for plotting CRTomo ERT inversion results and elem
% files, respectively
clear all; close all; clc;

%minimum depth for the plot
minz=-30;     

%color scale for resistivity  plot
res_min=1;    res_max=3.5;

%color scale for phase  plot
phi_min=0;    phi_max=25;

[fname,fpath]=uigetfile('./FEgrids/*.elm','Select the FE.elm file');

elem=dlmread([fpath fname]);

[fname,fpath]=uigetfile('./FEgrids/*.elc','Select the FE.elc file');
elec=dlmread([fpath fname]);

% reading the FE files
if elem(4,1)==11; headerrows=4; else headerrows=3; end    
header=elem(1:headerrows,:); elem(1:headerrows,:)=[]; 
coord=elem(1:header(1,1),:);  elem(1:header(1,1),:)=[];  
elem=elem(1:header(2,2),:);   
elec(1,:)=[]; elecind=coord(elec,1); elec(:,2:3)=coord(elecind,2:3);
elemind=coord(elem,1); elemx(:,1)=coord(elemind,2);
elemx=reshape(elemx,header(2,2),header(2,3)); elemx=elemx';
elemz(:,1)=coord(elemind,3); elemz=reshape(elemz,header(2,2),header(2,3));
elemz=elemz';

mmx=max(elec(:,2));

[fname,fpath]=uigetfile('*.mag','Select resistivity input file');
mag1=dlmread([fpath fname],'',1,0);

[fname,fpath]=uigetfile('*.pha','Select phase input file');
pha1=dlmread([fpath fname],'',1,0);

cov=dlmread([fpath 'coverage.mag'],'', [1 0 size(mag1,1) 2]);

for ii=1:size(mag1,1)
    if cov(ii,3)>-2.75
        mag(ii)=mag1(ii,3); pha(ii)=pha1(ii,3);
    else
        mag(ii)=NaN;
    end
end

set(figure,'units','normalized','outerposition',[0 0 1 1]);
subplot(2,1,1)
set(gcf,'color',[1 1 1])
hold on
caxis([res_min res_max])
plot(elec(:,2),elec(:,3),'.', ...
'MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',5)
patch(elemx,elemz,mag,'edgecolor','none') 
colormap(jet);
set(gca,'DataAspectRatio',[2 1 1],'TickDir','out','xtickMode','auto')
xlim([0 mmx]); ylim([minz 0]);
ylabel('z [m]'); xlabel('x [m]'); 
  h=colorbar('horizontal');
set(get(h,'xlabel'),'String',texlabel('log_1_0 rho, rho [Omega m]'),'fontsize',12)

subplot(2,1,2)
set(gcf,'color',[1 1 1])
hold on
caxis([phi_min phi_max])
plot(elec(:,2),elec(:,3),'.', ...
'MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',5)
patch(elemx,elemz,-pha,'edgecolor','none') 
colormap(jet);
set(gca,'DataAspectRatio',[2 1 1],'TickDir','out','xtickMode','auto')
xlim([0 mmx]); ylim([minz 0]);
ylabel('z [m]'); xlabel('x [m]'); 
  h=colorbar('horizontal');
set(get(h,'xlabel'),'String',texlabel('-phi [mrad]'),'fontsize',12)
